
From: Lennert Buytenhek <buytenh@marvell.com>
Subject: kernel: only build kernel-headers on ARM

Since kernels for different ARM CPUs differ wildly, and since
embedded folks tend to provide their own kernels, this patch makes
the Fedora kernel package only build kernel-headers when built for
ARM.

Signed-off-by: Lennert Buytenhek <buytenh@marvell.com>

Index: SPECS/kernel.spec
===================================================================
--- SPECS.orig/kernel.spec
+++ SPECS/kernel.spec
@@ -345,6 +345,14 @@ Summary: The Linux kernel (the core of t
 %define kernel_image vmlinux
 %endif
 
+%ifarch %{arm}
+%define all_arch_configs kernel-%{version}-arm*.config
+%define image_install_path boot
+%define hdrarch arm
+%define make_target vmlinux
+%define kernel_image vmlinux
+%endif
+
 %if %{nopatches}
 %define with_modsign 0
 # XXX temporary until last vdso patches are upstream
@@ -367,7 +375,7 @@ Summary: The Linux kernel (the core of t
 
 # We don't build a kernel on i386; we only do kernel-headers there,
 # and we no longer build for 31bit S390. Same for 32bit sparc.
-%define nobuildarches i386 s390 sparc
+%define nobuildarches i386 s390 sparc %{arm}
 
 %ifarch %nobuildarches
 %define with_up 0
@@ -447,10 +455,10 @@ Group: System Environment/Kernel
 License: GPLv2
 URL: http://www.kernel.org/
 Version: %{rpmversion}
-Release: %{pkg_release}
+Release: %{pkg_release}.fa1
 # DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
 # SET %%nobuildarches (ABOVE) INSTEAD
-ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64 sparc sparc64 s390x alpha alphaev56
+ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64 sparc sparc64 s390x alpha alphaev56 %{arm}
 ExclusiveOS: Linux
 
 %kernel_reqprovconf
@@ -528,6 +536,8 @@ Source90: config-sparc64-generic
 Source91: config-sparc64
 Source92: config-sparc64-smp
 
+Source100: config-arm
+
 %if %{using_upstream_branch}
 ### BRANCH PATCH ###
 %else
